==> react-form-builder-1.9.0.tgz: package/lib/Select/Default/index.js <==
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { useCallback } from 'react';
import PropTypes from 'prop-types';
import { field } from '../../prop-types';
import MoleculeSelectField from '@s-ui/react-molecule-select-field';
import MoleculeSelectOption from '@s-ui/react-molecule-dropdown-option';
import IconChevronDown from '../../Icons/IconChevronDown';

var DefaultSelect = function DefaultSelect(_ref) {
  var select = _ref.select,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      size = _ref.size,
      errors = _ref.errors;
  var errorMessages = errors[select.id];
  var onChangeCallback = useCallback(function (evt, _ref2) {
    var value = _ref2.value;
    return onChange(select.id, value);
  }, [onChange, select]);
  var _select$datalist = select.datalist,
      datalist = _select$datalist === void 0 ? [] : _select$datalist; // transform constraints to props

  var constraints = select.constraints || [];
  var constraintsProps = {};
  constraintsProps = constraints.reduce(function (acc, constraint) {
    var _constraint$property;

    if ((constraint === null || constraint === void 0 ? void 0 : (_constraint$property = constraint.property) === null || _constraint$property === void 0 ? void 0 : _constraint$property.notnull) === '') {
      return _objectSpread({}, acc, {
        required: true
      });
    } else {
      return acc;
    }
  }, constraintsProps);

  var selectProps = _objectSpread({
    id: select.id,
    label: select.label,
    name: select.name,
    placeholder: select.hint,
    iconArrowDown: React.createElement(IconChevronDown, null),
    value: select.value || '',
    onChange: onChangeCallback,
    tabIndex: tabIndex
  }, select.disabled && {
    disabled: true
  }, {}, select.hidden && {
    hidden: true
  }, {}, !!errorMessages && {
    errorText: errorMessages.join('\n')
  }, {
    selectSize: size
  }, constraintsProps);

  if (selectProps.hidden) {
    return null;
  }

  return React.createElement("div", {
    className: "sui-FormBuilder-field sui-FormBuilder-DefaultSelect sui-FormBuilder-" + selectProps.id
  }, selectProps.label && React.createElement("label", {
    className: "sui-FormBuilder-label",
    htmlFor: selectProps.id
  }, selectProps.label), React.createElement(MoleculeSelectField, selectProps, datalist.map(function (data) {
    return React.createElement(MoleculeSelectOption, {
      key: data.value,
      value: data.value
    }, data.text);
  })));
};

DefaultSelect.displayName = 'DefaultSelect';
export default React.memo(DefaultSelect);

==> react-form-builder-1.11.0.tgz: package/lib/Select/Default/index.js <==
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { useCallback } from 'react';
import PropTypes from 'prop-types';
import { field, createComponentMemo } from '../../prop-types';
import MoleculeSelectField from '@s-ui/react-molecule-select-field';
import MoleculeSelectOption from '@s-ui/react-molecule-dropdown-option';
import IconChevronDown from '../../Icons/IconChevronDown';

var DefaultSelect = function DefaultSelect(_ref) {
  var select = _ref.select,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      size = _ref.size,
      errors = _ref.errors;
  var errorMessages = errors[select.id];
  var onChangeCallback = useCallback(function (evt, _ref2) {
    var value = _ref2.value;
    return onChange(select.id, value);
  }, [onChange, select]);
  var _select$datalist = select.datalist,
      datalist = _select$datalist === void 0 ? [] : _select$datalist; // transform constraints to props

  var constraints = select.constraints || [];
  var constraintsProps = {};
  constraintsProps = constraints.reduce(function (acc, constraint) {
    var _constraint$property;

    if ((constraint === null || constraint === void 0 ? void 0 : (_constraint$property = constraint.property) === null || _constraint$property === void 0 ? void 0 : _constraint$property.notnull) === '') {
      return _objectSpread({}, acc, {
        required: true
      });
    } else {
      return acc;
    }
  }, constraintsProps);

  var selectProps = _objectSpread({
    id: select.id,
    label: select.label,
    name: select.name,
    placeholder: select.hint,
    iconArrowDown: React.createElement(IconChevronDown, null),
    value: select.value || '',
    onChange: onChangeCallback,
    tabIndex: tabIndex
  }, select.disabled && {
    disabled: true
  }, {}, select.hidden && {
    hidden: true
  }, {}, !!errorMessages && {
    errorText: errorMessages.join('\n')
  }, {
    selectSize: size
  }, constraintsProps);

  if (selectProps.hidden) {
    return null;
  }

  return React.createElement("div", {
    className: "sui-FormBuilder-field sui-FormBuilder-DefaultSelect sui-FormBuilder-" + selectProps.id
  }, selectProps.label && React.createElement("label", {
    className: "sui-FormBuilder-label",
    htmlFor: selectProps.id
  }, selectProps.label), React.createElement(MoleculeSelectField, selectProps, datalist.map(function (data) {
    return React.createElement(MoleculeSelectOption, {
      key: data.value,
      value: data.value
    }, data.text);
  })));
};

DefaultSelect.displayName = 'DefaultSelect';
export default React.memo(DefaultSelect, createComponentMemo('select'));
